import pytest  # type: ignore[import]

# noinspection PyUnresolvedReferences
from nhs_aws_helpers.fixtures import *  # noqa: F403
from tests.utils import temp_env_vars


@pytest.fixture(scope="session", autouse=True)
def autouse():
    with temp_env_vars(
        AWS_ENDPOINT_URL="http://localhost:4566",
        AWS_ACCESS_KEY_ID="dummy_access_key",
        AWS_SECRET_ACCESS_KEY="dummy_secret_key",
    ):
        yield



from nhs_aws_helpers import ecs_client, healthlake_client, iam_client, sts_client


def test_sts_client():
    client = sts_client()
    assert client.meta.service_model.service_id == "STS"


def test_healthlake_client():
    client = healthlake_client()
    assert client.meta.service_model.service_id == "HealthLake"


def test_ecs_client():
    client = ecs_client()
    assert client.meta.service_model.service_id == "ECS"


def test_iam_client():
    client = iam_client()
    assert client.meta.service_model.service_id == "IAM"
